==> lazycls-0.1.9.tar.gz: lazycls-0.1.9/lazy/utils/helpers.py <==
import time

from logz import get_logger, get_cls_logger
from lazy.static.timez import TimeValues
from lazy.models import BaseCls

class TimeResult(BaseCls):
    secs: float = 0.0
    mins: float = 0.0
    hrs: float = 0.0
    days: float = 0.0
    weeks: float = 0.0
    months: float = 0.0

    def get_string(self, short: bool = False, ksize: int = 4, nfloat: int = 5):
        s = ''
        d = self.dict()
        for key in {'secs', 'mins', 'hrs', 'days', 'weeks', 'months'}:
            if d.get(key):
                v = str(round(d[key], nfloat))
                k = key[:ksize] if short else key
                s += f' {v} {k}'
        return s.strip()

    @property
    def string(self):
        return self.get_string()

    @property
    def short(self):
        return self.get_string(short=True)


def to_time_string(t: float, short: bool = False, as_obj: bool = False):
    dict_val = {}
    curr_val = t
    for tkey, tnum in TimeValues.items():
        if curr_val > 0:
            curr_val, curr_num = divmod(curr_val, tnum)
            dict_val[tkey] = curr_num
    tcls = TimeResult(**dict_val)
    if as_obj: return tcls
    if short: return tcls.short
    return tcls.string



def timer(start: float = None, as_string: bool = False, short: bool = False, as_obj: bool = False, **kwargs):
    """
    Simple Timer Function that returns time.time 
    or result of start - now
    """
    if not start: return time.time()
    stop = (time.time() - start)
    if not as_string: return stop
    return to_time_string(stop, short=short, as_obj = as_obj)

==> lazycls-0.1.14.tar.gz: lazycls-0.1.14/lazy/utils/helpers.py <==
import time
import inspect

from logz import get_logger, get_cls_logger
from lazy.static.timez import TimeValues
from lazy.models import BaseCls


class TimeResult(BaseCls):
    secs: float = 0.0
    mins: float = 0.0
    hrs: float = 0.0
    days: float = 0.0
    weeks: float = 0.0
    months: float = 0.0

    def get_string(self, short: bool = False, ksize: int = 4, nfloat: int = 5):
        s = ''
        d = self.dict()
        for key in {'secs', 'mins', 'hrs', 'days', 'weeks', 'months'}:
            if d.get(key):
                v = str(round(d[key], nfloat))
                k = key[:ksize] if short else key
                s += f' {v} {k}'
        return s.strip()

    @property
    def string(self):
        return self.get_string()

    @property
    def short(self):
        return self.get_string(short=True)


def to_time_string(t: float, short: bool = False, as_obj: bool = False):
    dict_val = {}
    curr_val = t
    for tkey, tnum in TimeValues.items():
        if curr_val > 0:
            curr_val, curr_num = divmod(curr_val, tnum)
            dict_val[tkey] = curr_num
    tcls = TimeResult(**dict_val)
    if as_obj: return tcls
    if short: return tcls.short
    return tcls.string



def timer(start: float = None, as_string: bool = False, short: bool = False, as_obj: bool = False, **kwargs):
    """
    Simple Timer Function that returns time.time 
    or result of start - now
    """
    if not start: return time.time()
    stop = (time.time() - start)
    if not as_string: return stop
    return to_time_string(stop, short=short, as_obj = as_obj)


def is_coro_func(obj, func_name: str = None):
    """
    This is probably in the library elsewhere but returns bool
    based on if the function is a coro
    """
    if inspect.iscoroutinefunction(obj): return True
    if inspect.isawaitable(obj): return True
    if func_name and hasattr(obj, func_name) and inspect.iscoroutinefunction(getattr(obj, func_name)):
        return True
    if hasattr(obj, '__call__') and inspect.iscoroutinefunction(obj.__call__): return True
    return False
